==> coopr.extras-1.1.1.tar.gz: coopr.extras-1.1.1/setup.py <==
#  _________________________________________________________________________
#
#  Coopr: A COmmon Optimization Python Repository
#  Copyright (c) 2008 Sandia Corporation.
#  This software is distributed under the BSD License.
#  Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
#  the U.S. Government retains certain rights in this software.
#  _________________________________________________________________________

"""
Script to generate the installer for coopr.extras.
"""

import glob
import os
import sys

def _find_packages(path):
    """
    Generate a list of nested packages
    """
    pkg_list=[]
    if not os.path.exists(path):
        return []
    if not os.path.exists(path+os.sep+"__init__.py"):
        return []
    else:
        pkg_list.append(path)
    for root, dirs, files in os.walk(path, topdown=True):
        if root in pkg_list and "__init__.py" in files:
            for name in dirs:
                if os.path.exists(root+os.sep+name+os.sep+"__init__.py"):
                    pkg_list.append(root+os.sep+name)
    return map(lambda x:x.replace(os.sep,"."), pkg_list)

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

from pkg_resources import require, DistributionNotFound
required_packages = [
            'PuLP',
            'ecspy',
            'deap',
            #'pygene',   This is no longer available
            'suds',
            'PyYaml'
            ]
# The following require a successful NumPy install
try:
    require('numpy')
    #import numpy
    required_packages.append('openopt')
    required_packages.append('FuncDesigner')
    required_packages.append('DerApproximator')
    required_packages.append('mystic')
    #required_packages.append('sympy')
    #required_packages.append('cvexp')
except:
    pass
#
# As of 5 Sept 2012, Pyevolve only distributes binary eggs for 2.5/2.6
if sys.version_info[0:2] < (2,7):
    required_packages.append('Pyevolve')
    

from setuptools import setup
packages = _find_packages('coopr')

setup(name='coopr.extras',
      version='1.1.1',
      maintainer='William E. Hart',
      maintainer_email='wehart@sandia.gov',
      url = 'https://software.sandia.gov/coopr',
      license = 'BSD',
      platforms = ["any"],
      description = 'Extra packages that enhance the functionality of Coopr',
      long_description = read('README.txt'),
      classifiers = [
            'Development Status :: 4 - Beta',
            'Intended Audience :: End Users/Desktop',
            'Intended Audience :: Science/Research',
            'License :: OSI Approved :: BSD License',
            'Natural Language :: English',
            'Operating System :: Microsoft :: Windows',
            'Operating System :: Unix',
            'Programming Language :: Python',
            'Programming Language :: Unix Shell',
            'Topic :: Scientific/Engineering :: Mathematics',
            'Topic :: Software Development :: Libraries :: Python Modules'
        ],
      packages=packages,
      keywords=['optimization'],
      namespace_packages=['coopr'],
      install_requires=required_packages
      )

==> coopr.extras-1.1.2.tar.gz: coopr.extras-1.1.2/setup.py <==
#  _________________________________________________________________________
#
#  Coopr: A COmmon Optimization Python Repository
#  Copyright (c) 2008 Sandia Corporation.
#  This software is distributed under the BSD License.
#  Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
#  the U.S. Government retains certain rights in this software.
#  _________________________________________________________________________

"""
Script to generate the installer for coopr.extras.
"""

import glob
import os
import sys

def _find_packages(path):
    """
    Generate a list of nested packages
    """
    pkg_list=[]
    if not os.path.exists(path):
        return []
    if not os.path.exists(path+os.sep+"__init__.py"):
        return []
    else:
        pkg_list.append(path)
    for root, dirs, files in os.walk(path, topdown=True):
        if root in pkg_list and "__init__.py" in files:
            for name in dirs:
                if os.path.exists(root+os.sep+name+os.sep+"__init__.py"):
                    pkg_list.append(root+os.sep+name)
    return [pkg for pkg in map(lambda x:x.replace(os.sep,"."), pkg_list)]

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

from pkg_resources import require
required_packages = [
            'pyparsing==1.5.7',
            'PuLP',
            #'ecspy',   This has been deprecated  (use inspyred?)
            #'deap',     This doesn't seem to download
            #'pygene',   This is no longer available
            'suds',
            'PyYaml'
            ]
# The following require a successful NumPy install
try:
    require('numpy')
    #import numpy
    required_packages.append('openopt')
    required_packages.append('FuncDesigner')
    required_packages.append('DerApproximator')
    required_packages.append('mystic')
    #required_packages.append('sympy')
    #required_packages.append('cvexp')
except:
    pass
#
# As of 5 Sept 2012, Pyevolve only distributes binary eggs for 2.5/2.6
if sys.version_info[0:2] < (2,7):
    required_packages.append('Pyevolve')
    

from setuptools import setup
packages = _find_packages('coopr')

setup(name='coopr.extras',
      version='1.1.2',
      maintainer='William E. Hart',
      maintainer_email='wehart@sandia.gov',
      url = 'https://software.sandia.gov/svn/public/coopr/coopr.misc',
      license = 'BSD',
      platforms = ["any"],
      description = 'Extra packages that enhance the functionality of Coopr',
      long_description = read('README.txt'),
      classifiers = [
            'Development Status :: 4 - Beta',
            'Intended Audience :: End Users/Desktop',
            'Intended Audience :: Science/Research',
            'License :: OSI Approved :: BSD License',
            'Natural Language :: English',
            'Operating System :: Microsoft :: Windows',
            'Operating System :: Unix',
            'Programming Language :: Python',
            'Programming Language :: Unix Shell',
            'Topic :: Scientific/Engineering :: Mathematics',
            'Topic :: Software Development :: Libraries :: Python Modules',
            'Topic :: Scientific/Engineering'
        ],
      packages=packages,
      keywords=['optimization'],
      namespace_packages=['coopr'],
      install_requires=required_packages
      )
